From 0a9bb8ba73f80fd63592d994c837345698131e9b Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Bj=C3=B6rn=20Schie=C3=9Fle?= <schiessle@owncloud.com>
Date: Fri, 26 Jul 2013 15:15:47 +0200
Subject: [PATCH] reduce time for auto expire to 30 days by default

---
 apps/files_trashbin/lib/trash.php | 2 +-
 config/config.sample.php          | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/apps/files_trashbin/lib/trash.php b/apps/files_trashbin/lib/trash.php
index d09c4d5f7b1..ba940084a87 100644
--- a/apps/files_trashbin/lib/trash.php
+++ b/apps/files_trashbin/lib/trash.php
@@ -25,7 +25,7 @@ namespace OCA\Files_Trashbin;
 class Trashbin {
 	// how long do we keep files in the trash bin if no other value is defined in the config file (unit: days)
 
-	const DEFAULT_RETENTION_OBLIGATION = 180;
+	const DEFAULT_RETENTION_OBLIGATION = 30;
 
 	// unit: percentage; 50% of available disk space/quota
 	const DEFAULTMAXSIZE = 50;
diff --git a/config/config.sample.php b/config/config.sample.php
index 4d1950d60ee..8d978ea6ee7 100644
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -114,8 +114,8 @@ $CONFIG = array(
 /* Password to use for sendmail mail, depends on mail_smtpauth if this is used */
 "mail_smtppassword" => "",
 
-/* How long should ownCloud keep deleted files in the trash bin, default value:  180 days */
-'trashbin_retention_obligation' => 180,
+/* How long should ownCloud keep deleted files in the trash bin, default value:  30 days */
+'trashbin_retention_obligation' => 30,
 
 /* allow user to change his display name, if it is supported by the back-end */
 'allow_user_to_change_display_name' => true,
-- 
GitLab